package handlers

import (
	"fmt"
	"golias/broker"
	"golias/config"
	"golias/pkg/cache"
	"html/template"
	"log/slog"
	"net/http"
	"os"
	"time"
)

var (
	log      *slog.Logger
	cfg      *config.Config
	memcache cache.Cache
	Notifier *broker.Broker
)

func init() {
	log = slog.New(slog.NewJSONHandler(os.Stderr, &slog.HandlerOptions{
		Level:     slog.LevelDebug,
		AddSource: true,
	}))
	memcache = cache.MemCache
	cfg = config.LoadConfigOrDefault("")
	Notifier = broker.NewBroker()
	go Notifier.Listen()
	ticker := time.NewTicker(2 * time.Second)
	go func() {
		counter := 0
		for {
			<-ticker.C
			Notifier.Notifier <- broker.NotificationEvent{
				EventName: "test",
				Payload:   fmt.Sprintf("%v test call of notifier", counter),
			}
			counter++
		}
	}()
}

var roundWords = map[string]string{
	"hamster":    "blue",
	"child":      "red",
	"wheel":      "white",
	"condition":  "black",
	"test":       "white",
	"ball":       "blue",
	"violin":     "red",
	"rat":        "white",
	"perplexity": "blue",
	"notion":     "red",
	"guitar":     "blue",
	"ocean":      "blue",
	"moon":       "blue",
	"coffee":     "blue",
	"mountain":   "blue",
	"book":       "blue",
	"camera":     "blue",
	"apple":      "red",
	"fire":       "red",
	"rose":       "red",
	"sun":        "red",
	"cherry":     "red",
	"heart":      "red",
	"tomato":     "red",
	"cloud":      "white",
}

func HandlePing(w http.ResponseWriter, r *http.Request) {
	w.Write([]byte("pong"))
}

func HandleHome(w http.ResponseWriter, r *http.Request) {
	tmpl, err := template.ParseGlob("components/*.html")
	if err != nil {
		abortWithError(w, err.Error())
		return
	}
	fi, _ := getFullInfoByCtx(r.Context())
	if fi != nil && fi.Room != nil && fi.State != nil {
		if fi.State.Role == "mime" {
			fi.Room.RevealAllCards()
		}
	}
	if fi != nil && fi.Room == nil {
		fi.List = listPublicRooms()
	}
	if err := tmpl.ExecuteTemplate(w, "base", fi); err != nil {
		log.Error("failed to exec templ;", "error", err, "templ", "base")
	}
}
